# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [
      ./hardware.nix
      ./local.nix
      ./includes/cli
      ./includes/desktop
      ./includes/local-dns
      ./includes/kubernetes
    ];

  nixpkgs.config.allowUnfree = true;

  networking.networkmanager.enable = true;

  i18n = {
    consoleFont = "Lat2-Terminus16";
    consoleKeyMap = "us";
    defaultLocale = "en_US.UTF-8";
  };

  # Set your time zone.
  time.timeZone = "Asia/Tokyo";

  # Enable sound.
  sound.enable = true;
  hardware.pulseaudio.enable = true;

  virtualisation.libvirtd = {
    enable = true;
    onBoot = "ignore";
  };

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.thomas = {
    isNormalUser = true;
    extraGroups = [ "wheel" "video" "networkmanager" "libvirt" ];
    shell = pkgs.zsh;
  };

  nix.gc = {
    automatic = true;
    options = "--delete-older-then 14d";
  };
  systemd.timers.nix-gc.timerConfig.Persistent = true;

  # This value determines the NixOS release with which your system is to be
  # compatible, in order to avoid breaking some software such as database
  # servers. You should change this only after NixOS release notes say you
  # should.
  system.stateVersion = "19.09"; # Did you read the comment?
}
